==> root-framework_6.24.06-1.debian.tar.xz: debian/settings.cmake <==
# CMake settings
set (CMAKE_CXX_STANDARD 17 CACHE STRING "" FORCE)
set (CMAKE_INSTALL_PYTHONDIR lib/python3/dist-packages CACHE PATH "" FORCE)
set (CMAKE_INSTALL_SYSCONFDIR /etc/root CACHE PATH "" FORCE)

# install settings
set (fail-on-missing ON CACHE BOOL "" FORCE)
set (gnuinstall ON CACHE BOOL "" FORCE)
set (soversion ON CACHE BOOL "" FORCE)
set (shared ON CACHE BOOL "" FORCE)
set (gsl_shared ON CACHE BOOL "" FORCE)

# disable C++ module
set (cxxmodules OFF CACHE BOOL "" FORCE)
set (runtime_cxxmodules OFF CACHE BOOL "" FORCE)

# enable heavily patched builtin llvm component
set (builtin_clang ON CACHE BOOL "" FORCE)
set (builtin_cling ON CACHE BOOL "" FORCE)
set (builtin_llvm ON CACHE BOOL "" FORCE)

# disable other builtins when possible
set (builtin_afterimage OFF CACHE BOOL "" FORCE)
set (builtin_cfitsio OFF CACHE BOOL "" FORCE)
set (builtin_davix OFF CACHE BOOL "" FORCE)
set (builtin_fftw3 OFF CACHE BOOL "" FORCE)
set (builtin_freetype OFF CACHE BOOL "" FORCE)
set (builtin_ftgl OFF CACHE BOOL "" FORCE)
set (builtin_gl2ps OFF CACHE BOOL "" FORCE)
set (builtin_glew OFF CACHE BOOL "" FORCE)
set (builtin_gsl OFF CACHE BOOL "" FORCE)
set (builtin_lz4 OFF CACHE BOOL "" FORCE)
set (builtin_lzma OFF CACHE BOOL "" FORCE)
set (builtin_nlohmannjson OFF CACHE BOOL "" FORCE)
set (builtin_openssl OFF CACHE BOOL "" FORCE)
set (builtin_openui5 ON CACHE BOOL "" FORCE)  # openui5 to be packaged
set (builtin_pcre OFF CACHE BOOL "" FORCE)
set (builtin_tbb OFF CACHE BOOL "" FORCE)
set (builtin_unuran ON CACHE BOOL "" FORCE)  # unuran to be packaged
set (builtin_vc OFF CACHE BOOL "" FORCE)
set (builtin_vdt ON CACHE BOOL "" FORCE)  # vdt to be packaged
set (builtin_veccore OFF CACHE BOOL "" FORCE)
set (builtin_xrootd OFF CACHE BOOL "" FORCE)
set (builtin_xxhash OFF CACHE BOOL "" FORCE)
set (builtin_zlib OFF CACHE BOOL "" FORCE)
set (builtin_zstd OFF CACHE BOOL "" FORCE)

# optional features
set (alien OFF CACHE BOOL "" FORCE)
set (arrow OFF CACHE BOOL "" FORCE)
set (asimage ON CACHE BOOL "" FORCE)
set (clad OFF CACHE BOOL "" FORCE)
set (cuda OFF CACHE BOOL "" FORCE)
set (cudnn OFF CACHE BOOL "" FORCE)
set (dataframe ON CACHE BOOL "" FORCE)
set (davix ON CACHE BOOL "" FORCE)
set (dcache ON CACHE BOOL "" FORCE)
set (fcgi ON CACHE BOOL "" FORCE)
set (fftw3 ON CACHE BOOL "" FORCE)
set (fitsio ON CACHE BOOL "" FORCE)
set (fortran ON CACHE BOOL "" FORCE)
set (gdml ON CACHE BOOL "" FORCE)
set (gfal ON CACHE BOOL "" FORCE)
set (gl2ps ON CACHE BOOL "" FORCE)
set (gviz ON CACHE BOOL "" FORCE)
set (http ON CACHE BOOL "" FORCE)
set (imt ON CACHE BOOL "" FORCE)
set (mathmore ON CACHE BOOL "" FORCE)
set (minimal OFF CACHE BOOL "" FORCE)
set (minuit2 ON CACHE BOOL "" FORCE)
set (minuit2_mpi ON CACHE BOOL "" FORCE)
set (minuit2_omp ON CACHE BOOL "" FORCE)
set (mlp ON CACHE BOOL "" FORCE)
set (monalisa OFF CACHE BOOL "" FORCE)
set (mpi ON CACHE BOOL "" FORCE)
set (mysql ON CACHE BOOL "" FORCE)
set (odbc ON CACHE BOOL "" FORCE)
set (opengl ON CACHE BOOL "" FORCE)
set (oracle OFF CACHE BOOL "" FORCE)
set (pgsql ON CACHE BOOL "" FORCE)
set (pyroot ON CACHE BOOL "" FORCE)
set (pythia6 OFF CACHE BOOL "" FORCE)
set (pythia8 OFF CACHE BOOL "" FORCE)  # pythia8 to be packaged
set (qt5web ON CACHE BOOL "" FORCE)
set (r ON CACHE BOOL "" FORCE)
set (roofit ON CACHE BOOL "" FORCE)
set (root7 ON CACHE BOOL "" FORCE)
set (shadowpw ON CACHE BOOL "" FORCE)
set (spectrum ON CACHE BOOL "" FORCE)
set (sqlite ON CACHE BOOL "" FORCE)
set (ssl ON CACHE BOOL "" FORCE)
set (tmva ON CACHE BOOL "" FORCE)
set (tmva-cpu ON CACHE BOOL "" FORCE)
set (tmva-gpu OFF CACHE BOOL "" FORCE)
set (tmva-pymva ON CACHE BOOL "" FORCE)
set (tmva-rmva ON CACHE BOOL "" FORCE)
set (unuran ON CACHE BOOL "" FORCE)
set (vdt ON CACHE BOOL "" FORCE)
set (veccore ON CACHE BOOL "" FORCE)
set (vecgeom OFF CACHE BOOL "" FORCE)  # vecgeom implementation is buggy
set (vmc OFF CACHE BOOL "" FORCE)
set (webgui ON CACHE BOOL "" FORCE)
set (x11 ON CACHE BOOL "" FORCE)
set (xml ON CACHE BOOL "" FORCE)
set (xrootd ON CACHE BOOL "" FORCE)

==> root-framework_6.26.06-1.debian.tar.xz: debian/settings.cmake <==
# CMake settings
set (CMAKE_CXX_STANDARD 17 CACHE STRING "" FORCE)
set (CMAKE_INSTALL_PYTHONDIR lib/python3/dist-packages CACHE PATH "" FORCE)
set (CMAKE_INSTALL_SYSCONFDIR /etc/root CACHE PATH "" FORCE)

# install settings
set (fail-on-missing ON CACHE BOOL "" FORCE)
set (gnuinstall ON CACHE BOOL "" FORCE)
set (soversion ON CACHE BOOL "" FORCE)
set (shared ON CACHE BOOL "" FORCE)
set (gsl_shared ON CACHE BOOL "" FORCE)

# build settings
set (ccache ON CACHE BOOL "" FORCE)
set (asserts OFF CACHE BOOL "" FORCE)
set (dev OFF CACHE BOOL "" FORCE)

# disable C++ module
set (cxxmodules OFF CACHE BOOL "" FORCE)
set (runtime_cxxmodules OFF CACHE BOOL "" FORCE)

# enable heavily patched builtin llvm component
set (builtin_clang ON CACHE BOOL "" FORCE)  # still needs to patches (possible contact person: hahnjo@hahnjo.de)
set (builtin_cling ON CACHE BOOL "" FORCE)  # build cling with clang-repl once above fixed
set (builtin_llvm ON CACHE BOOL "" FORCE)  # works once https://github.com/root-project/root/pull/10294 merged

# disable other builtins when possible
set (builtin_afterimage OFF CACHE BOOL "" FORCE)
set (builtin_cfitsio OFF CACHE BOOL "" FORCE)
set (builtin_cppzmq OFF CACHE BOOL "" FORCE)
set (builtin_davix OFF CACHE BOOL "" FORCE)
set (builtin_fftw3 OFF CACHE BOOL "" FORCE)
set (builtin_freetype OFF CACHE BOOL "" FORCE)
set (builtin_ftgl OFF CACHE BOOL "" FORCE)
set (builtin_gl2ps OFF CACHE BOOL "" FORCE)
set (builtin_glew OFF CACHE BOOL "" FORCE)
set (builtin_gsl OFF CACHE BOOL "" FORCE)
set (builtin_lz4 OFF CACHE BOOL "" FORCE)
set (builtin_lzma OFF CACHE BOOL "" FORCE)
set (builtin_nlohmannjson OFF CACHE BOOL "" FORCE)
set (builtin_openssl OFF CACHE BOOL "" FORCE)
set (builtin_openui5 OFF CACHE BOOL "" FORCE)  # openui5 to be packaged
set (builtin_pcre OFF CACHE BOOL "" FORCE)
set (builtin_tbb OFF CACHE BOOL "" FORCE)
set (builtin_unuran OFF CACHE BOOL "" FORCE)
set (builtin_vc OFF CACHE BOOL "" FORCE)
set (builtin_vdt OFF CACHE BOOL "" FORCE)
set (builtin_veccore OFF CACHE BOOL "" FORCE)
set (builtin_xrootd OFF CACHE BOOL "" FORCE)
set (builtin_xxhash OFF CACHE BOOL "" FORCE)
set (builtin_zeromq OFF CACHE BOOL "" FORCE)
set (builtin_zlib OFF CACHE BOOL "" FORCE)
set (builtin_zstd OFF CACHE BOOL "" FORCE)

# optional features
set (alien OFF CACHE BOOL "" FORCE)
set (arrow OFF CACHE BOOL "" FORCE)
set (asimage ON CACHE BOOL "" FORCE)
set (clad OFF CACHE BOOL "" FORCE)
set (cuda OFF CACHE BOOL "" FORCE)
set (cudnn OFF CACHE BOOL "" FORCE)
set (dataframe ON CACHE BOOL "" FORCE)
set (davix ON CACHE BOOL "" FORCE)
set (dcache ON CACHE BOOL "" FORCE)
set (fcgi ON CACHE BOOL "" FORCE)
set (fftw3 ON CACHE BOOL "" FORCE)
set (fitsio ON CACHE BOOL "" FORCE)
set (fortran ON CACHE BOOL "" FORCE)
set (gdml ON CACHE BOOL "" FORCE)
set (gfal ON CACHE BOOL "" FORCE)
set (gl2ps ON CACHE BOOL "" FORCE)
set (gviz ON CACHE BOOL "" FORCE)
set (http ON CACHE BOOL "" FORCE)
set (imt ON CACHE BOOL "" FORCE)
set (mathmore ON CACHE BOOL "" FORCE)
set (minimal OFF CACHE BOOL "" FORCE)
set (minuit2 ON CACHE BOOL "" FORCE)
set (minuit2_mpi ON CACHE BOOL "" FORCE)
set (minuit2_omp ON CACHE BOOL "" FORCE)
set (mlp ON CACHE BOOL "" FORCE)
set (monalisa OFF CACHE BOOL "" FORCE)
set (mpi ON CACHE BOOL "" FORCE)
set (mysql ON CACHE BOOL "" FORCE)
set (odbc ON CACHE BOOL "" FORCE)
set (opengl ON CACHE BOOL "" FORCE)
set (oracle OFF CACHE BOOL "" FORCE)
set (pgsql ON CACHE BOOL "" FORCE)
set (pyroot ON CACHE BOOL "" FORCE)
set (pythia6 OFF CACHE BOOL "" FORCE)
set (pythia8 OFF CACHE BOOL "" FORCE)  # pythia8 to be packaged
set (qt5web ON CACHE BOOL "" FORCE)
set (qt6web ON CACHE BOOL "" FORCE)
set (r ON CACHE BOOL "" FORCE)
set (roofit_hs3_ryml OFF CACHE BOOL "" FORCE)  # Rapid YAML to be packaged
set (roofit_multiprocess OFF CACHE BOOL "" FORCE)  # requires zmq_ppoll see https://bugs.debian.org/1011073
set (roofit ON CACHE BOOL "" FORCE)
set (root7 ON CACHE BOOL "" FORCE)
set (shadowpw ON CACHE BOOL "" FORCE)
set (spectrum ON CACHE BOOL "" FORCE)
set (sqlite ON CACHE BOOL "" FORCE)
set (ssl ON CACHE BOOL "" FORCE)
set (tmva ON CACHE BOOL "" FORCE)
set (tmva-cpu ON CACHE BOOL "" FORCE)
set (tmva-gpu OFF CACHE BOOL "" FORCE)
set (tmva-pymva ON CACHE BOOL "" FORCE)
set (tmva-rmva ON CACHE BOOL "" FORCE)
set (tmva-sofie ON CACHE BOOL "" FORCE)
set (unuran ON CACHE BOOL "" FORCE)
set (uring ON CACHE BOOL "" FORCE)
set (vdt ON CACHE BOOL "" FORCE)
set (veccore ON CACHE BOOL "" FORCE)
set (vecgeom OFF CACHE BOOL "" FORCE)  # vecgeom implementation does not work due to being compiled with C++20
set (webgui OFF CACHE BOOL "" FORCE)  # requires openui5
set (x11 ON CACHE BOOL "" FORCE)
set (xml ON CACHE BOOL "" FORCE)
set (xrootd ON CACHE BOOL "" FORCE)
